@@ -10,7 +10,6 @@
 #include "akonadi_search_pim_debug.h"
 #include "contactquery.h"
 
-#include <QDebug>
 #include <QVariant>
 
 #include <Akonadi/ServerManager>
@@ -20,13 +19,9 @@
 
 using namespace Akonadi::Search::PIM;
 
-Query::Query()
-{
-}
+Query::Query() = default;
 
-Query::~Query()
-{
-}
+Query::~Query() = default;
 
 Query *Query::fromJSON(const QByteArray &json)
 {
